@@ -965,6 +965,9 @@ def policy_maintenance_set(context,  # pylint: disable=too-many-branches, too-ma
     """
     if not any([filter_, id_]):
         raise click.UsageError("--id or --filter is required")
+    if all([start_date, end_date]):
+        if pendulum.parse(start_date) > pendulum.parse(end_date):
+            raise click.UsageError("the start-date can't be later than the end-date")
     if filter_:
         id_ = []
         filters_enabled = []
